@@ -32,7 +32,6 @@ Here is a minimal deployable pattern definition:
 const { DynamoDBStreamToLambdaProps,  DynamoDBStreamToLambda} = require('@aws-solutions-constructs/aws-dynamodb-stream-lambda');
 
 const props: DynamoDBStreamToLambdaProps = {
-    deployLambda: true,
     lambdaFunctionProps: {
         code: lambda.Code.asset(`${__dirname}/lambda`),
         runtime: lambda.Runtime.NODEJS_12_X,
@@ -60,9 +59,8 @@ new DynamoDBStreamToLambda(scope: Construct, id: string, props: DynamoDBStreamTo
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|deployLambda|`boolean`|Whether to create a new Lambda function or use an existing Lambda function|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object|
-|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|Optional user provided props to override the default props for Lambda function|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.|
+|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |dynamoTableProps?|[`dynamodb.TableProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.TableProps.html)|Optional user provided props to override the default props for DynamoDB Table|
 |existingTableObj?|[`dynamodb.Table`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.Table.html)|Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored|
 |dynamoEventSourceProps?|[`aws-lambda-event-sources.DynamoEventSourceProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda-event-sources.DynamoEventSourceProps.html)|Optional user provided props to override the default props for DynamoDB Event Source|
@@ -127,7 +125,6 @@ class DynamoDBStreamToLambda(
         scope: aws_cdk.core.Construct,
         id: str,
         *,
-        deploy_lambda: bool,
         dynamo_event_source_props: typing.Optional[
             aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps
         ] = None,
@@ -139,12 +136,11 @@ class DynamoDBStreamToLambda(
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param dynamo_event_source_props: Optional user provided props to override the default props. Default: - Default props are used
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param existing_table_obj: Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored. Default: - None
-        :param lambda_function_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
         access:
         :access:: public
@@ -154,7 +150,6 @@ class DynamoDBStreamToLambda(
         :summary:: Constructs a new instance of the LambdaToDynamoDB class.
         """
         props = DynamoDBStreamToLambdaProps(
-            deploy_lambda=deploy_lambda,
             dynamo_event_source_props=dynamo_event_source_props,
             dynamo_table_props=dynamo_table_props,
             existing_lambda_obj=existing_lambda_obj,
@@ -179,7 +174,6 @@ class DynamoDBStreamToLambda(
     jsii_type="@aws-solutions-constructs/aws-dynamodb-stream-lambda.DynamoDBStreamToLambdaProps",
     jsii_struct_bases=[],
     name_mapping={
-        "deploy_lambda": "deployLambda",
         "dynamo_event_source_props": "dynamoEventSourceProps",
         "dynamo_table_props": "dynamoTableProps",
         "existing_lambda_obj": "existingLambdaObj",
@@ -191,7 +185,6 @@ class DynamoDBStreamToLambdaProps:
     def __init__(
         self,
         *,
-        deploy_lambda: bool,
         dynamo_event_source_props: typing.Optional[
             aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps
         ] = None,
@@ -201,12 +194,11 @@ class DynamoDBStreamToLambdaProps:
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
         """
-        :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param dynamo_event_source_props: Optional user provided props to override the default props. Default: - Default props are used
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param existing_table_obj: Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored. Default: - None
-        :param lambda_function_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
         summary:
         :summary:: The properties for the DynamoDBStreamToLambda Construct
@@ -221,9 +213,7 @@ class DynamoDBStreamToLambdaProps:
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
                 **lambda_function_props
             )
-        self._values = {
-            "deploy_lambda": deploy_lambda,
-        }
+        self._values = {}
         if dynamo_event_source_props is not None:
             self._values["dynamo_event_source_props"] = dynamo_event_source_props
         if dynamo_table_props is not None:
@@ -235,17 +225,6 @@ class DynamoDBStreamToLambdaProps:
         if lambda_function_props is not None:
             self._values["lambda_function_props"] = lambda_function_props
 
-    @builtins.property
-    def deploy_lambda(self) -> bool:
-        """Whether to create a new lambda function or use an existing lambda function.
-
-        If set to false, you must provide a lambda function object as ``existingObj``
-
-        default
-        :default: - true
-        """
-        return self._values.get("deploy_lambda")
-
     @builtins.property
     def dynamo_event_source_props(
         self,
@@ -268,9 +247,7 @@ class DynamoDBStreamToLambdaProps:
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """Existing instance of Lambda Function object.
-
-        If ``deploy`` is set to false only then this property is required
+        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
         default
         :default: - None
@@ -290,9 +267,7 @@ class DynamoDBStreamToLambdaProps:
     def lambda_function_props(
         self,
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
-        """Optional user provided props to override the default props.
-
-        If ``deploy`` is set to true only then this property is required
+        """User provided props to override the default props for the Lambda function.
 
         default
         :default: - Default props are used
